Summary:       An elegant unit testing framework for C with support for mock objects
Name:          cmocka
Version:       1.1.7
Release:       2%{?dist}
License:       ASL 2.0
URL:           https://cmocka.org
Source0:       %{url}/files/1.1/%{name}-%{version}.tar.xz

BuildRequires: gcc cmake doxygen glibc-devel gnupg2

%description
There are a variety of C unit testing frameworks available however many of them are fairly complex and
require the latest compiler technology. Some development requires the use of old compilers which makes
it difficult to use some unit testing frameworks. In addition many unit testing frameworks assume the code
being tested is an application or module that is targeted to the same platform that will ultimately
execute the test. Because of this assumption many frameworks require the inclusion of standard C library
headers in the code module being tested which may collide with the custom or incomplete implementation of
the C library utilized by the code under test.

Cmocka only requires a test application is linked with the standard C library which minimizes conflicts
with standard C library headers. Also, CMocka tries to avoid the use of some of the newer features of C
compilers.

This results in CMocka being a relatively small library that can be used to test a variety of exotic code.
If a developer wishes to simply test an application with the latest compiler then other unit testing
frameworks may be preferable.

This is the successor of Google's Cmockery.

%package -n libcmocka
Summary:        Lightweight library to simplify and generalize unit tests for C

Conflicts: cmockery2

%description -n libcmocka
There are a variety of C unit testing frameworks available however many of them are fairly complex and
require the latest compiler technology. Some development requires the use of old compilers which makes
it difficult to use some unit testing frameworks. In addition many unit testing frameworks assume the code
being tested is an application or module that is targeted to the same platform that will ultimately
execute the test. Because of this assumption many frameworks require the inclusion of standard C library
headers in the code module being tested which may collide with the custom or incomplete implementation of
the C library utilized by the code under test.

Cmocka only requires a test application is linked with the standard C library which minimizes conflicts
with standard C library headers. Also, CMocka tries to avoid the use of some of the newer features of C
compilers.

This results in CMocka being a relatively small library that can be used to test a variety of exotic code.
If a developer wishes to simply test an application with the latest compiler then other unit testing
frameworks may be preferable.

This is the successor of Google's Cmockery.

%package -n libcmocka-static
Summary:        Lightweight library to simplify and generalize unit tests for C

%description -n libcmocka-static
Static version of the cmocka library.

%package -n libcmocka-devel
Summary:        Development headers for the cmocka library
Requires:       libcmocka = %{version}-%{release}

Conflicts: cmockery2-devel

%description -n libcmocka-devel
Development headers for the cmocka unit testing library.

%prep
%autosetup -n %{name}-%{version} -p1

%build
%define _lto_cflags %{nil}
%cmake \
    -DWITH_STATIC_LIB=ON \
    -DWITH_CMOCKERY_SUPPORT=ON \
    -DUNIT_TESTING=ON \
    %{nil}

%cmake_build
%__cmake --build %{__cmake_builddir}

%install
%cmake_install
ln -s libcmocka.so %{buildroot}%{_libdir}/libcmockery.so
install -p %{_target_platform}/src/libcmocka-static.a %{buildroot}%{_libdir}

%check
%ctest

%files -n libcmocka
%license COPYING
%doc AUTHORS README.md ChangeLog
%{_libdir}/libcmocka.so.*

%files -n libcmocka-static
%{_libdir}/libcmocka-static.a

%files -n libcmocka-devel
%{_includedir}/cmocka.h
%{_includedir}/cmocka_pbc.h
%{_includedir}/cmockery/cmockery.h
%{_includedir}/cmockery/pbc.h
%{_libdir}/libcmocka.so
%{_libdir}/libcmockery.so
%{_libdir}/pkgconfig/cmocka.pc
%{_libdir}/cmake/cmocka/cmocka-config*.cmake

%changelog
* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.1.7-2
- Rebuilt for OpenCloudOS Stream 23.09

* Wed Aug 2 2023 Shuo Wang <abushwang@tencent.com> - 1.1.7-1
- update to 1.1.7

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.1.5-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.1.5-2
- Rebuilt for OpenCloudOS Stream 23

* Tue Jan 31 2023 Shuo Wang <abushwang@tencent.com> - 1.1.5-1
- initial build
